@@ -4,11 +4,12 @@ from datetime import datetime, timedelta
 from time import sleep
 from selenium import webdriver
 from selenium.webdriver.common.keys import Keys
+from selenium.webdriver.support import expected_conditions as EC
 import re
 
 __author__ = """Matt Burke"""
 __email__ = 'matttsburke@gmail.com'
-__version__ = '1.3.0'
+__version__ = '1.3.2'
 
 next_swipe = datetime.now
 visited_ids = []
@@ -34,7 +35,10 @@ def login(chromedriver, username, password, headless=False, login_url=default_lo
         browser.delete_all_cookies()
         browser.set_window_size(1200, 1080)
         browser.get(login_url)
-        sleep(9)
+        wait = WebDriverWait(browser, 10)
+        element = wait.until(EC.element_to_be_clickable(find_element_by_name("post")))
+
+        #sleep(9)
         # s = browser.page_source
         # pattern = "id=\"password(.*?)\""
         # code=re.search(pattern, s).group(1)
@@ -43,7 +47,7 @@ def login(chromedriver, username, password, headless=False, login_url=default_lo
         sleep(2)
         browser.find_element_by_name("password").send_keys(password)
         browser.find_element_by_name("post").click()
-        sleep(5)
+        #sleep(5)
         connected = True
     except:
         connected = False
@@ -135,9 +139,11 @@ def visit_many(ids, like=False):
             visit(id, like)
 
 
-def get_profile_data(id, like=False):
+def get_profile_data(id, like, screenshot_dir, photo_dir):
     profile_data = {}
     source = visit(id, like)
+    if screenshot_dir:
+        browser.save_screenshot(screenshot_dir+id+".png")        
     soup = BeautifulSoup((source), features="lxml")
     try:
         nameandage=soup.title.string.split(" |")[0]
